=========
Changelog
=========

Version 1.1.1
=============

- [fix] Fixed retrieval of Pygments parameters from Mau configuration

Version 1.1.0
=============

- [enhancement] Added template for RawNode nodes
- [fix] Accept *args and **kwargs in visit functions

Version 1.0.0
=============

- A working initial implementation

